/***************************************************************
 * Name:      wx001Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-04-04
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif
#include <wx/imagpng.h>

#include "wx001Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx001Frame, wxFrame)
    EVT_CLOSE(wx001Frame::OnClose)
    EVT_MENU(idMenuQuit, wx001Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx001Frame::OnAbout)
    EVT_MENU(idMenuCheck, wx001Frame::OnCheck)
    EVT_MENU_RANGE(idMenuRadio1, idMenuRadio3, wx001Frame::OnRadio)
END_EVENT_TABLE()

wx001Frame::wx001Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title), marca(false), radio(2)
{
    wxImage::AddHandler(new wxPNGHandler);
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));

    fileMenu->Append(idMenuAbrir, _("&Abrir...\tCtrl-F"), _("Abrir un documento"))->SetBitmap(wxBITMAP_PNG(bmabrir16));

//wxMenuItem *abrir = fileMenu->Append(idMenuAbrir, _("&Abrir...\tCtrl-F"), _("Abrir un documento"));
//abrir->SetBitmap(wxBITMAP_PNG(bmabrir16)); //.FromFiles("open-file16x16.png"));

    fileMenu->Append(-1, _T(""), _T(""), wxITEM_SEPARATOR);
    wxMenuItem *guardar = fileMenu->Append(idMenuGuardar, _("&Guardar...\tCtrl-S"), _("Guardar un documento")); //->SetBitmap(wxBITMAP_PNG(bmsalvar16));
    wxBitmapBundle bmb;
    guardar->SetBitmap(bmb.FromFiles("save-file16x16.png"));

    fileMenu->Append(idMenuQuit, _("&Salir\tAlt-F4"), _("Abandonar la aplicacin"));
    fileMenu->Append(-1, _T(""), _T(""), wxITEM_SEPARATOR);//  (idMenuQuit, _("&Quit\tAlt-F4"), _("Quit the application"));
    wxMenuItem *item = new wxMenuItem(__null, idMenuCheck, _("&Marcar\tF3"), _("Opcin marcable"), wxITEM_CHECK);
    fileMenu->Append(item);
    fileMenu->Append(idMenuRadio1, _("Radio &1\tF5"), _("Item radio 1"), wxITEM_RADIO);
    fileMenu->Append(idMenuRadio2, _("Radio &2\tF6"), _("Item radio 2"), wxITEM_RADIO);
    fileMenu->Append(idMenuRadio3, _("Radio &3\tF7"), _("Item radio 3"), wxITEM_RADIO);
    mbar->Append(fileMenu, _("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _("&Sobre...\tF1"), _("Muestra informacin sobre sta aplicacin"));
    mbar->Append(helpMenu, _("&Ayuda"));

    SetMenuBar(mbar);

    item->Check(marca);
    fileMenu->Enable(idMenuRadio3, false);
    mbar->FindItem(idMenuRadio1+radio)->Check();

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola usuario de Code::Blocks!"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}


wx001Frame::~wx001Frame()
{
}

void wx001Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx001Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx001Frame::OnCheck(wxCommandEvent& event) {
    marca = event.IsChecked();
}

void wx001Frame::OnRadio(wxCommandEvent& event) {
    radio = event.GetId() - idMenuRadio1;
}

void wx001Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _("Bienvenido a ..."));
}
